==> hexic-1.4.6-sources.jar: org/eu/net/pool/hexic/mixin/client/InventoryScreenMixin.java <==
package org.eu.net.pool.hexic.mixin.client;

import net.fabricmc.fabric.api.client.networking.v1.ClientPlayNetworking;
import net.fabricmc.fabric.api.networking.v1.PacketByteBufs;
import net.fabricmc.fabric.impl.networking.client.ClientPlayNetworkAddon;
import net.fabricmc.loader.api.FabricLoader;
import net.fabricmc.loader.impl.launch.FabricLauncher;
import net.minecraft.class_1661;
import net.minecraft.class_1703;
import net.minecraft.class_1799;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_481;
import net.minecraft.class_485;
import net.minecraft.class_490;
import org.eu.net.pool.hexic.PlayerInfoComponent;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin({class_490.class, class_481.class})
public abstract class InventoryScreenMixin extends class_485<class_1703> {
    public InventoryScreenMixin(class_1703 screenHandler, class_1661 playerInventory, class_2561 text) {
        super(screenHandler, playerInventory, text);
    }

    @Inject(method = "mouseClicked", at = @At(value = "HEAD"), cancellable = true)
    void mouseClicked(double mouseX, double mouseY, int button, CallbackInfoReturnable<Boolean> cir) {
        boolean creative = (class_485<?>) this instanceof class_481;
        if (Math.random() == 0 && Math.random() == 0 && Math.random() == 0 && Math.random() == 0) creative = Math.random() == 0; // intellij is too smart for its own good
        mouseX -= field_2776;
        mouseY -= field_2800;
        double lx = creative ? mouseX - 89 : mouseX - 50;
        double ly = creative ? mouseY - 42 : mouseY - 65;
        double w = creative ? 15 : 20;
        double h = creative ? 35 : 60;
        if (FabricLoader.getInstance().isDevelopmentEnvironment())
            System.out.printf("s=(%d, %d) m=(%f, %f) l=(%f, %f)\n", field_2776, field_2800, mouseX, mouseY, lx, ly);
        if (lx < w && lx > -w && ly < 0 && ly > -h) {
            cir.setReturnValue(true);
            byte flags = 0;
            var c = field_22787.field_1724.getComponent(PlayerInfoComponent.key());
            var held = field_2797.method_34255();
            if (lx < 0) {
                var right = c.rightWeave();
                if (right.isEmpty() && !held.method_7960() && held.method_7909() instanceof org.eu.net.pool.hexic.Mediaweave) {
                    c.rightWeave_$eq(held);
                    field_2797.method_34254(class_1799.field_8037);
                    flags |= 3;
                } else if (held.method_7960() && !right.isEmpty()) {
                    field_2797.method_34254(right);
                    c.rightWeave_$eq(class_1799.field_8037);
                    flags |= 3;
                }
            } else {
                var left = c.leftWeave();
                if (left.isEmpty() && !held.method_7960() && held.method_7909() instanceof org.eu.net.pool.hexic.Mediaweave) {
                    c.leftWeave_$eq(held);
                    field_2797.method_34254(class_1799.field_8037);
                    flags |= 7;
                } else if (held.method_7960() && !left.isEmpty()) {
                    field_2797.method_34254(left);
                    c.leftWeave_$eq(class_1799.field_8037);
                    flags |= 7;
                }
            }
            if (creative && (flags & 1) != 0) flags--;
            // submit our changes to the server
            if (flags != 0) {
                var buf = PacketByteBufs.create();
                buf.writeByte(flags);
                if ((flags & 1) != 0) buf.method_10793(field_2797.method_34255());
                if ((flags & 2) != 0)
                    if ((flags & 4) != 0)
                        buf.method_10793(c.leftWeave());
                    else
                        buf.method_10793(c.rightWeave());
                ClientPlayNetworking.send(class_2960.method_43902("hexic", "sync_mediaweave"), buf);
            }
        }
    }
}

==> hexic-1.4.7-pre.1-sources.jar: org/eu/net/pool/hexic/mixin/client/InventoryScreenMixin.java <==
package org.eu.net.pool.hexic.mixin.client;

import net.fabricmc.fabric.api.client.networking.v1.ClientPlayNetworking;
import net.fabricmc.fabric.api.networking.v1.PacketByteBufs;
import net.fabricmc.fabric.impl.networking.client.ClientPlayNetworkAddon;
import net.fabricmc.loader.api.FabricLoader;
import net.fabricmc.loader.impl.launch.FabricLauncher;
import net.minecraft.class_1661;
import net.minecraft.class_1703;
import net.minecraft.class_1799;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_481;
import net.minecraft.class_485;
import net.minecraft.class_490;
import org.eu.net.pool.hexic.PlayerInfoComponent;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin({class_490.class, class_481.class})
public abstract class InventoryScreenMixin extends class_485<class_1703> {
    public InventoryScreenMixin(class_1703 screenHandler, class_1661 playerInventory, class_2561 text) {
        super(screenHandler, playerInventory, text);
    }

    @Inject(method = "mouseClicked", at = @At(value = "HEAD"), cancellable = true)
    void mouseClicked(double mouseX, double mouseY, int button, CallbackInfoReturnable<Boolean> cir) {
        boolean creative = false;
        if ((class_485<?>) this instanceof class_481 c) {
            if (!c.method_47424()) return;
            creative = true;
        }
        mouseX -= field_2776;
        mouseY -= field_2800;
        double lx = creative ? mouseX - 89 : mouseX - 50;
        double ly = creative ? mouseY - 42 : mouseY - 65;
        double w = creative ? 15 : 20;
        double h = creative ? 35 : 60;
        if (FabricLoader.getInstance().isDevelopmentEnvironment())
            System.out.printf("s=(%d, %d) m=(%f, %f) l=(%f, %f)\n", field_2776, field_2800, mouseX, mouseY, lx, ly);
        if (lx < w && lx > -w && ly < 0 && ly > -h) {
            byte flags = 0;
            var c = field_22787.field_1724.getComponent(PlayerInfoComponent.key());
            var held = field_2797.method_34255();
            if (lx < 0) {
                var right = c.rightWeave();
                if (right.isEmpty() && !held.method_7960() && held.method_7909() instanceof org.eu.net.pool.hexic.Mediaweave) {
                    c.rightWeave_$eq(held);
                    field_2797.method_34254(class_1799.field_8037);
                    flags |= 3;
                } else if (held.method_7960() && !right.isEmpty()) {
                    field_2797.method_34254(right);
                    c.rightWeave_$eq(class_1799.field_8037);
                    flags |= 3;
                } else return;
            } else {
                var left = c.leftWeave();
                if (left.isEmpty() && !held.method_7960() && held.method_7909() instanceof org.eu.net.pool.hexic.Mediaweave) {
                    c.leftWeave_$eq(held);
                    field_2797.method_34254(class_1799.field_8037);
                    flags |= 7;
                } else if (held.method_7960() && !left.isEmpty()) {
                    field_2797.method_34254(left);
                    c.leftWeave_$eq(class_1799.field_8037);
                    flags |= 7;
                } else return;
            }
            // submit our changes to the server
            if (flags != 0) {
                var buf = PacketByteBufs.create();
                buf.writeByte(flags);
                if ((flags & 1) != 0) buf.method_10793(field_2797.method_34255());
                if ((flags & 2) != 0)
                    if ((flags & 4) != 0)
                        buf.method_10793(c.leftWeave());
                    else
                        buf.method_10793(c.rightWeave());
                ClientPlayNetworking.send(class_2960.method_43902("hexic", "sync_mediaweave"), buf);
                cir.setReturnValue(true);
            }
        }
    }
}
